# OpenAPI Schemas for Pydantic

<!-- markdownlint-disable -->
<p align="center">
  <a href="https://esmerald.dymmond.com"><img src="https://res.cloudinary.com/dymmond/image/upload/v1664911052/esmerald/img/logo-green_uwjmcc.png" alt='Esmerald'></a>
</p>

**Documentation**: [https://openapi-schemas.dymmond.com](https://openapi-schemas.dymmond.com) 📚

**Source Code**: [https://www.github.com/dymmond/openapi-schemas-pydantic](https://www.github.com/dymmond/openapi-schemas-pydantic)

This library is a fork of [pydantic-openapi-schema](https://github.com/starlite-api/pydantic-openapi-schema).

The library solved some known issues from the previous also forked repo and we have plans of continuing to support the fork as
well. 

## Why the fork?

We want to make sure we are able to add extras unique to [Esmerald](https://esmerald.dymmond.com) without
bothering Starlite with someting that might not even be their scope. If we find common ground we will be also
contribute to Starlite to make sure they also get the latest if they don't have it already.

We support everything opensource.

Usage is mostly identical to upstream package.


## Installation

```shell
pip install openapi-schemas-pydantic
```

## Contributing

Check the [contributing](openapi-schemas.dymmond.com/contributing) documentation and see how you can help.
